==> item-descriptions-2.5.3%2B1.21.10-fabric-sources.jar: cc/cassian/item_descriptions/client/mixin/StatusEffectsDisplayMixin.java <==
package cc.cassian.item_descriptions.client.mixin;

import cc.cassian.item_descriptions.client.helpers.ModHelpers;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import com.llamalad7.mixinextras.sugar.ref.LocalBooleanRef;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.Collection;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_1293;
import net.minecraft.class_2561;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_485;
import net.minecraft.class_5632;

//? if >1.21.2 {
@Mixin(class_485.class)
//?} else
/*@Mixin(EffectRenderingInventoryScreen.class)*/
public abstract class StatusEffectsDisplayMixin {

    //? if =1.21.5 || =1.21.4 {
    /*@Shadow protected abstract void renderLabels(GuiGraphics context, int x, int height, Iterable<MobEffectInstance> statusEffects);


    @Inject(method = "renderEffects", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/screens/inventory/EffectsInInventory;renderIcons(Lnet/minecraft/client/gui/GuiGraphics;IILjava/lang/Iterable;Z)V"))
    private void forceShowDescriptions(GuiGraphics context, int mouseX, int mouseY, CallbackInfo ci, @Local LocalBooleanRef booleanRef, @Local(ordinal = 2) int i, @Local Collection<MobEffectInstance> collection, @Local Iterable<MobEffectInstance> iterable) {
        if (booleanRef.get()) {
            int k = 33;
            if (collection.size() > 5) {
                k = 132 / (collection.size() - 1);
            }
            this.renderLabels(context, i, k, iterable);
        }
        booleanRef.set(false);
    }

    *///?}

    //? if >1.21.10 {
    /*@WrapOperation(method = "renderText", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;setTooltipForNextFrame(Lnet/minecraft/client/gui/Font;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(GuiGraphics instance, Font font, List<Component> lines, Optional<TooltipComponent> tooltipImage, int x, int y, Operation<Void> original) {
        List<Component> tooltipText = ModHelpers.createEffectDescription(lines);
        original.call(instance, font, tooltipText, tooltipImage, x, y);
    }

    @Inject(method = "renderText", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/GuiGraphics;drawString(Lnet/minecraft/client/gui/Font;Lnet/minecraft/util/FormattedCharSequence;III)V"))
    private void forceShowDescriptions(GuiGraphics context, MobEffectInstance mobEffectInstance, Component component, Font font, int i, int j, int k, int l, int m, int n, CallbackInfo ci, @Local LocalBooleanRef bl) {
        if (!bl.get())
            bl.set(true);
    }

    *///?} else if >1.21.5 {
    @Shadow protected abstract void renderLabels(class_332 context, int x, int height, Iterable<class_1293> statusEffects);

    @Redirect(method = "renderTooltip", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;setTooltipForNextFrame(Lnet/minecraft/client/gui/Font;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(class_332 context, class_327 textRenderer, List<class_2561> text, Optional<class_5632> data, int mouseX, int mouseY) {
        List<class_2561> tooltipText = ModHelpers.createEffectDescription(text);
        context.method_51434(textRenderer, tooltipText, mouseX, mouseY);
    }
    @Inject(method = "renderEffects", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/screens/inventory/EffectsInInventory;renderIcons(Lnet/minecraft/client/gui/GuiGraphics;IILjava/lang/Iterable;Z)V"))
    private void forceShowDescriptions(class_332 context, int mouseX, int mouseY, CallbackInfo ci, @Local LocalBooleanRef booleanRef, @Local(ordinal = 2) int i, @Local Collection<class_1293> collection, @Local Iterable<class_1293> iterable) {
        if (booleanRef.get()) {
            int k = 33;
            if (collection.size() > 5) {
                k = 132 / (collection.size() - 1);
            }
            this.renderLabels(context, i, k, iterable);
        }
        booleanRef.set(false);
    }

    //?} else if >1.21.1 {
    /*@Redirect(method = "renderEffects", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;renderTooltip(Lnet/minecraft/client/gui/Font;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(GuiGraphics context, Font textRenderer, List<Component> text, Optional<TooltipComponent> data, int mouseX, int mouseY) {
        List<Component> tooltipText = ModHelpers.createEffectDescription(text);
        context.renderTooltip(textRenderer, tooltipText, Optional.empty(), mouseX, mouseY);
    }
    *///?} else if >1.20 {
    /*@Redirect(method = "renderEffects", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;renderTooltip(Lnet/minecraft/client/gui/Font;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(GuiGraphics context, Font textRenderer, List<Component> text, Optional data, int mouseX, int mouseY) {
        List<Component> tooltipText = ModHelpers.createEffectDescription(text);
        context.renderTooltip(textRenderer, tooltipText, Optional.empty(), mouseX, mouseY);
    }
    @Shadow protected abstract void renderLabels(GuiGraphics context, int x, int height, Iterable<MobEffectInstance> statusEffects);

    @Inject(method = "renderEffects", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/screens/inventory/EffectRenderingInventoryScreen;renderIcons(Lnet/minecraft/client/gui/GuiGraphics;IILjava/lang/Iterable;Z)V"))
    private void forceShowDescriptions(GuiGraphics context, int mouseX, int mouseY, CallbackInfo ci, @Local LocalBooleanRef booleanRef, @Local(ordinal = 2) int i, @Local Collection<MobEffectInstance> collection, @Local Iterable<MobEffectInstance> iterable) {
        if (booleanRef.get()) {
            int k = 33;
            if (collection.size() > 5) {
                k = 132 / (collection.size() - 1);
            }
            this.renderLabels(context, i, k, iterable);
        }
        booleanRef.set(false);
    }
    *///?} else {
    /*@Shadow protected abstract void drawMobEffectDescriptions(MatrixStack matrices, int x, int height, Iterable<MobEffectInstance> statusEffects);

    @Redirect(method = "drawMobEffects", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/screen/ingame/AbstractInventoryScreen;renderTooltip(Lnet/minecraft/client/util/math/MatrixStack;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(AbstractInventoryScreen instance, MatrixStack stack, List<Text> text, Optional optional, int mouseX, int mouseY) {
        List<Text> tooltipText = ModHelpers.createEffectDescription(text);
        instance.renderTooltip(stack, tooltipText, Optional.empty(), mouseX, mouseY);
    }

    @Inject(method = "drawMobEffects", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/screen/ingame/AbstractInventoryScreen;drawMobEffectSprites(Lnet/minecraft/client/util/math/MatrixStack;IILjava/lang/Iterable;Z)V"))
    private void forceShowDescriptions(MatrixStack matrices, int mouseX, int mouseY, CallbackInfo ci, @Local LocalBooleanRef booleanRef, @Local(ordinal = 2) int i, @Local Collection<MobEffectInstance> collection, @Local Iterable<MobEffectInstance> iterable) {
        if (booleanRef.get()) {
            int k = 33;
            if (collection.size() > 5) {
                k = 132 / (collection.size() - 1);
            }
            this.drawMobEffectDescriptions(matrices, i, k, iterable);
        }
        booleanRef.set(false);
    }
    *///?}

}

==> item-descriptions-2.5.4%2B1.20.1-fabric-sources.jar: cc/cassian/item_descriptions/client/mixin/StatusEffectsDisplayMixin.java <==
package cc.cassian.item_descriptions.client.mixin;

import cc.cassian.item_descriptions.client.helpers.ModHelpers;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import com.llamalad7.mixinextras.sugar.ref.LocalBooleanRef;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.Collection;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_1293;
import net.minecraft.class_2561;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_485;

//? if >1.21.2 {
/*@Mixin(EffectsInInventory.class)
*///?} else
@Mixin(class_485.class)
public abstract class StatusEffectsDisplayMixin {

    //? if =1.21.5 || =1.21.4 {
    /*@Shadow protected abstract void renderLabels(GuiGraphics context, int x, int height, Iterable<MobEffectInstance> statusEffects);


    @Inject(method = "renderEffects", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/screens/inventory/EffectsInInventory;renderIcons(Lnet/minecraft/client/gui/GuiGraphics;IILjava/lang/Iterable;Z)V"))
    private void forceShowDescriptions(GuiGraphics context, int mouseX, int mouseY, CallbackInfo ci, @Local LocalBooleanRef booleanRef, @Local(ordinal = 2) int i, @Local Collection<MobEffectInstance> collection, @Local Iterable<MobEffectInstance> iterable) {
        if (booleanRef.get()) {
            int k = 33;
            if (collection.size() > 5) {
                k = 132 / (collection.size() - 1);
            }
            this.renderLabels(context, i, k, iterable);
        }
        booleanRef.set(false);
    }

    *///?}

    //? if >1.21.10 {
    /*@WrapOperation(method = "renderText", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;setTooltipForNextFrame(Lnet/minecraft/client/gui/Font;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(GuiGraphics instance, Font font, List<Component> lines, Optional<TooltipComponent> tooltipImage, int x, int y, Operation<Void> original) {
        List<Component> tooltipText = ModHelpers.createEffectDescription(lines);
        original.call(instance, font, tooltipText, tooltipImage, x, y);
    }

    @Inject(method = "renderText", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/GuiGraphics;drawString(Lnet/minecraft/client/gui/Font;Lnet/minecraft/util/FormattedCharSequence;III)V"))
    private void forceShowDescriptions(GuiGraphics context, MobEffectInstance mobEffectInstance, Component component, Font font, int i, int j, int k, int l, int m, int n, CallbackInfo ci, @Local LocalBooleanRef bl) {
        if (!bl.get())
            bl.set(true);
    }

    *///?} else if >1.21.5 {
    /*@Shadow protected abstract void renderLabels(GuiGraphics context, int x, int height, Iterable<MobEffectInstance> statusEffects);

    @Redirect(method = "renderTooltip", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;setTooltipForNextFrame(Lnet/minecraft/client/gui/Font;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(GuiGraphics context, Font textRenderer, List<Component> text, Optional<TooltipComponent> data, int mouseX, int mouseY) {
        List<Component> tooltipText = ModHelpers.createEffectDescription(text);
        context.setComponentTooltipForNextFrame(textRenderer, tooltipText, mouseX, mouseY);
    }
    @Inject(method = "renderEffects", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/screens/inventory/EffectsInInventory;renderIcons(Lnet/minecraft/client/gui/GuiGraphics;IILjava/lang/Iterable;Z)V"))
    private void forceShowDescriptions(GuiGraphics context, int mouseX, int mouseY, CallbackInfo ci, @Local LocalBooleanRef booleanRef, @Local(ordinal = 2) int i, @Local Collection<MobEffectInstance> collection, @Local Iterable<MobEffectInstance> iterable) {
        if (booleanRef.get()) {
            int k = 33;
            if (collection.size() > 5) {
                k = 132 / (collection.size() - 1);
            }
            this.renderLabels(context, i, k, iterable);
        }
        booleanRef.set(false);
    }

    *///?} else if >1.21.1 {
    /*@Redirect(method = "renderEffects", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;renderTooltip(Lnet/minecraft/client/gui/Font;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(GuiGraphics context, Font textRenderer, List<Component> text, Optional<TooltipComponent> data, int mouseX, int mouseY) {
        List<Component> tooltipText = ModHelpers.createEffectDescription(text);
        context.renderTooltip(textRenderer, tooltipText, Optional.empty(), mouseX, mouseY);
    }
    *///?} else if >1.20 {
    @Redirect(method = "renderEffects", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;renderTooltip(Lnet/minecraft/client/gui/Font;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(class_332 context, class_327 textRenderer, List<class_2561> text, Optional data, int mouseX, int mouseY) {
        List<class_2561> tooltipText = ModHelpers.createEffectDescription(text);
        context.method_51437(textRenderer, tooltipText, Optional.empty(), mouseX, mouseY);
    }
    @Shadow protected abstract void renderLabels(class_332 context, int x, int height, Iterable<class_1293> statusEffects);

    @Inject(method = "renderEffects", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/screens/inventory/EffectRenderingInventoryScreen;renderIcons(Lnet/minecraft/client/gui/GuiGraphics;IILjava/lang/Iterable;Z)V"))
    private void forceShowDescriptions(class_332 context, int mouseX, int mouseY, CallbackInfo ci, @Local LocalBooleanRef booleanRef, @Local(ordinal = 2) int i, @Local Collection<class_1293> collection, @Local Iterable<class_1293> iterable) {
        if (booleanRef.get()) {
            int k = 33;
            if (collection.size() > 5) {
                k = 132 / (collection.size() - 1);
            }
            this.renderLabels(context, i, k, iterable);
        }
        booleanRef.set(false);
    }
    //?} else {
    /*@Shadow protected abstract void renderLabels(PoseStack matrices, int x, int height, Iterable<MobEffectInstance> statusEffects);

    @Redirect(method = "renderEffects", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/screens/inventory/EffectRenderingInventoryScreen;renderTooltip(Lcom/mojang/blaze3d/vertex/PoseStack;Ljava/util/List;Ljava/util/Optional;II)V"))
    private void renderEffects(EffectRenderingInventoryScreen instance, PoseStack stack, List<Component> text, Optional optional, int mouseX, int mouseY) {
        List<Component> tooltipText = ModHelpers.createEffectDescription(text);
        instance.renderTooltip(stack, tooltipText, Optional.empty(), mouseX, mouseY);
    }

    @Inject(method = "renderEffects", at = @At(value = "INVOKE", shift = At.Shift.AFTER, target = "Lnet/minecraft/client/gui/screens/inventory/EffectRenderingInventoryScreen;renderIcons(Lcom/mojang/blaze3d/vertex/PoseStack;IILjava/lang/Iterable;Z)V"))
    private void forceShowDescriptions(PoseStack matrices, int mouseX, int mouseY, CallbackInfo ci, @Local LocalBooleanRef booleanRef, @Local(ordinal = 2) int i, @Local Collection<MobEffectInstance> collection, @Local Iterable<MobEffectInstance> iterable) {
        if (booleanRef.get()) {
            int k = 33;
            if (collection.size() > 5) {
                k = 132 / (collection.size() - 1);
            }
            this.renderLabels(matrices, i, k, iterable);
        }
        booleanRef.set(false);
    }
    *///?}

}
